
#ifndef _GDFONTS_H_
#define _GDFONTS_H_ 1

/*
	This is a header file for gd font, generated using
	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
	from bdf font
	-Gemini-Fixed-Medium-R-SemiCondensed--13-120-75-75-C-60-KOI8-U
	at Tue Jan 29 07:24:08 2002.
	The original bdf was holding following copyright:
	"Copyright (C) 1994 Cronyx Ltd."
 */


#include "gd.h"

extern gdFontPtr gdFontSmall;

#endif

